@@ -1,5 +1,5 @@
 package JSON::RPC::Dispatcher;
-our $VERSION = '0.0502';
+our $VERSION = '0.0503';
 
 =head1 NAME
 
@@ -7,7 +7,7 @@ JSON::RPC::Dispatcher - A JSON-RPC 2.0 server.
 
 =head1 VERSION
 
-version 0.0502
+version 0.0503
 
 =head1 SYNOPSIS
 
@@ -145,18 +145,21 @@ has error_code => (
     is          => 'rw',
     default     => undef,
     predicate   => 'has_error_code',
+    clearer     => 'clear_error_code',
 );
 
 #--------------------------------------------------------
 has error_message => (
     is      => 'rw',
     default => undef,
+    clearer => 'clear_error_message',
 );
 
 #--------------------------------------------------------
 has error_data  => (
     is      => 'rw',
     default => undef,
+    clearer => 'clear_error_data',
 );
 
 #--------------------------------------------------------
@@ -165,6 +168,15 @@ has rpcs => (
     default => sub { {} },
 );
 
+#--------------------------------------------------------
+sub clear_error {
+    my ($self) = @_;
+
+    $self->clear_error_code;
+    $self->clear_error_message;
+    $self->clear_error_data;
+}
+
 #--------------------------------------------------------
 sub register {
     my ($self, $name, $sub, $options) = @_;
@@ -355,6 +367,7 @@ sub call {
 
     my $request = Plack::Request->new($env);
     $log->info("REQUEST: ".$request->content) if $log->is_info;
+    $self->clear_error;
     my $procs = $self->acquire_procedures($request);
 
     my $rpc_response;
